@@ -6,11 +6,11 @@ import click
 
 coloredlogs.install(level=logging.DEBUG)
 
-from packers import mzip_packer
 from packers import elf_packer
+from packers import mzip_packer
 from packers import raw_packer
 
-PACKERS = [elf_packer, raw_packer, mzip_packer]
+PACKERS = [elf_packer, mzip_packer, raw_packer]
 
 
 @click.command()
